==========================================
Traversal based asyncronious web framework
==========================================

.. image:: https://api.travis-ci.org/zzzsochi/aiotraversal.svg
  :target:  https://secure.travis-ci.org/zzzsochi/aiotraversal
  :align: right

.. image:: https://coveralls.io/repos/zzzsochi/aiotraversal/badge.svg
  :target:  https://coveralls.io/r/zzzsochi/aiotraversal
  :align: right

This is framework, around `aiohttp_traversal <https://github.com/zzzsochi/aiohttp_traversal>`_.

-----
Tests
-----

.. code:: shell

    $ pip install pytest
    $ py.test
